@@ -1,9 +1,10 @@
 /************************************************************************
  *
- * $Id: geos_c.cpp 2975 2010-04-17 21:55:53Z strk $
+ * $Id: geos_c.cpp 3322 2011-05-03 02:27:00Z sgillies $
  *
  * C-Wrapper for GEOS library
  *
+ * Copyright (C) 2010 2011 Sandro Santilli <strk@keybit.net>
  * Copyright (C) 2005-2006 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
@@ -39,6 +40,7 @@
 #define GEOSWKTWriter_t geos::io::WKTWriter
 #define GEOSWKBReader_t geos::io::WKBReader
 #define GEOSWKBWriter_t geos::io::WKBWriter
+typedef struct GEOSBufParams_t GEOSBufferParams;
 
 #include "geos_c.h"
 
@@ -85,11 +87,6 @@ GEOSContextHandle_t handle = NULL;
 
 extern "C" {
 
-GEOSMessageHandler
-GEOSContext_setNoticeHandler_r(GEOSContextHandle_t extHandle, GEOSMessageHandler nf);
-GEOSMessageHandler
-GEOSContext_setErrorHandler_r(GEOSContextHandle_t extHandle, GEOSMessageHandler nf);
-
 void
 initGEOS (GEOSMessageHandler nf, GEOSMessageHandler ef)
 {
@@ -170,6 +167,18 @@ GEOSOverlaps(const Geometry *g1, const Geometry *g2)
     return GEOSOverlaps_r( handle, g1, g2 );
 }
 
+char
+GEOSCovers(const Geometry *g1, const Geometry *g2)
+{
+    return GEOSCovers_r( handle, g1, g2 );
+}
+
+char
+GEOSCoveredBy(const Geometry *g1, const Geometry *g2)
+{
+    return GEOSCoveredBy_r( handle, g1, g2 );
+}
+
 
 //-------------------------------------------------------------------
 // low-level relate functions
@@ -181,12 +190,23 @@ GEOSRelatePattern(const Geometry *g1, const Geometry *g2, const char *pat)
     return GEOSRelatePattern_r( handle, g1, g2, pat );
 }
 
+char
+GEOSRelatePatternMatch(const char *mat, const char *pat)
+{
+    return GEOSRelatePatternMatch_r( handle, mat, pat );
+}
+
 char *
 GEOSRelate(const Geometry *g1, const Geometry *g2)
 {
     return GEOSRelate_r( handle, g1, g2 );
 }
 
+char *
+GEOSRelateBoundaryNodeRule(const Geometry *g1, const Geometry *g2, int bnr)
+{
+    return GEOSRelateBoundaryNodeRule_r( handle, g1, g2, bnr );
+}
 
 
 //-----------------------------------------------------------------
@@ -206,6 +226,13 @@ GEOSisValidReason(const Geometry *g1)
     return GEOSisValidReason_r( handle, g1 );
 }
 
+char
+GEOSisValidDetail(const Geometry *g, int flags,
+	char** reason, Geometry ** location)
+{
+    return GEOSisValidDetail_r( handle, g, flags, reason, location );
+}
+
 //-----------------------------------------------------------------
 // general purpose
 //-----------------------------------------------------------------
@@ -366,6 +393,14 @@ GEOSSingleSidedBuffer(const Geometry *g1, double width, int quadsegs,
                                joinStyle, mitreLimit, leftSide );
 }
 
+Geometry *
+GEOSOffsetCurve(const Geometry *g1, double width, int quadsegs,
+	int joinStyle, double mitreLimit)
+{
+    return GEOSOffsetCurve_r( handle, g1, width, quadsegs, 
+                               joinStyle, mitreLimit );
+}
+
 Geometry *
 GEOSConvexHull(const Geometry *g1)
 {
@@ -396,6 +431,12 @@ GEOSUnion(const Geometry *g1, const Geometry *g2)
     return GEOSUnion_r( handle, g1, g2 );
 }
 
+Geometry *
+GEOSUnaryUnion(const Geometry *g1)
+{
+    return GEOSUnaryUnion_r( handle, g1);
+}
+
 Geometry *
 GEOSUnionCascaded(const Geometry *g1)
 {
@@ -465,6 +506,83 @@ GEOSGetGeometryN(const Geometry *g1, int n)
     return GEOSGetGeometryN_r( handle, g1, n );
 }
 
+/*
+ * Call only on LINESTRING
+ * Returns NULL on exception
+ */
+Geometry *
+GEOSGeomGetPointN(const Geometry *g1, int n)
+{
+	return GEOSGeomGetPointN_r(handle, g1, n);
+}
+
+/*
+ * Call only on LINESTRING
+ */
+Geometry *
+GEOSGeomGetStartPoint(const Geometry *g1)
+{
+	return GEOSGeomGetStartPoint_r(handle, g1);
+}
+
+/*
+ * Call only on LINESTRING
+ */
+Geometry *
+GEOSGeomGetEndPoint(const Geometry *g1)
+{
+	return GEOSGeomGetEndPoint_r(handle, g1);
+}
+
+/*
+ * Call only on LINESTRING
+ * return 2 on exception, 1 on true, 0 on false
+ */
+char
+GEOSisClosed(const Geometry *g1)
+{
+	return GEOSisClosed_r(handle, g1);
+}
+
+/*
+ * Call only on LINESTRING
+ * returns 0 on exception, otherwise 1
+ */
+int
+GEOSGeomGetLength(const Geometry *g1, double *length)
+{
+	return GEOSGeomGetLength_r(handle, g1, length);
+}
+
+/*
+ * Call only on LINESTRING
+ * returns -1 on exception
+ */
+int
+GEOSGeomGetNumPoints(const Geometry *g1)
+{
+	return GEOSGeomGetNumPoints_r(handle, g1);
+}
+
+/*
+ * For POINT
+ * returns 0 on exception, otherwise 1
+ */
+int
+GEOSGeomGetX(const Geometry *g1, double *x)
+{
+	return GEOSGeomGetX_r(handle, g1, x);
+}
+
+/*
+ * For POINT
+ * returns 0 on exception, otherwise 1
+ */
+int
+GEOSGeomGetY(const Geometry *g1, double *y)
+{
+	return GEOSGeomGetY_r(handle, g1, y);
+}
 
 /*
  * Call only on polygon
@@ -510,6 +628,13 @@ GEOSPolygonizer_getCutEdges(const Geometry * const * g, unsigned int ngeoms)
     return GEOSPolygonizer_getCutEdges_r( handle, g, ngeoms );
 }
 
+GEOSGeometry *
+GEOSPolygonize_full(const GEOSGeometry* input,
+	GEOSGeometry** cuts, GEOSGeometry** dangles, GEOSGeometry** invalid)
+{
+    return GEOSPolygonize_full_r(handle, input, cuts, dangles, invalid );
+}
+
 Geometry *
 GEOSLineMerge(const Geometry *g)
 {
@@ -679,6 +804,12 @@ GEOSGeom_getDimensions(const Geometry *g)
     return GEOSGeom_getDimensions_r( handle, g );
 }
 
+int
+GEOSGeom_getCoordinateDimension(const Geometry *g)
+{
+    return GEOSGeom_getCoordinateDimension_r( handle, g );
+}
+
 Geometry *
 GEOSSimplify(const Geometry *g1, double tolerance)
 {
@@ -725,13 +856,42 @@ GEOSWKTWriter_destroy(WKTWriter *Writer)
     GEOSWKTWriter_destroy_r( handle, Writer );
 }
 
-
 char*
 GEOSWKTWriter_write(WKTWriter *writer, const Geometry *geom)
 {
     return GEOSWKTWriter_write_r( handle, writer, geom );
 }
 
+void
+GEOSWKTWriter_setTrim(WKTWriter *writer, char trim)
+{
+	GEOSWKTWriter_setTrim_r(handle, writer, trim);
+}
+
+void
+GEOSWKTWriter_setRoundingPrecision(WKTWriter *writer, int precision)
+{
+	return GEOSWKTWriter_setRoundingPrecision_r(handle, writer, precision);
+}
+
+void
+GEOSWKTWriter_setOutputDimension(WKTWriter *writer, int dim)
+{
+	GEOSWKTWriter_setOutputDimension_r(handle, writer, dim);
+}
+
+int
+GEOSWKTWriter_getOutputDimension(WKTWriter *writer)
+{
+	return GEOSWKTWriter_getOutputDimension_r(handle, writer);
+}
+
+void
+GEOSWKTWriter_setOld3D(WKTWriter *writer, int useOld3D)
+{
+	GEOSWKTWriter_setOld3D_r(handle, writer, useOld3D);
+}
+
 /* WKB Reader */
 WKBReader *
 GEOSWKBReader_create()
@@ -851,18 +1011,54 @@ GEOSPreparedContainsProperly(const geos::geom::prep::PreparedGeometry *pg1, cons
     return GEOSPreparedContainsProperly_r( handle, pg1, g2 );
 }
 
+char
+GEOSPreparedCoveredBy(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
+{
+    return GEOSPreparedCoveredBy_r( handle, pg1, g2 );
+}
+
 char
 GEOSPreparedCovers(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
 {
     return GEOSPreparedCovers_r( handle, pg1, g2 );
 }
 
+char
+GEOSPreparedCrosses(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
+{
+    return GEOSPreparedCrosses_r( handle, pg1, g2 );
+}
+
+char
+GEOSPreparedDisjoint(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
+{
+    return GEOSPreparedDisjoint_r( handle, pg1, g2 );
+}
+
 char
 GEOSPreparedIntersects(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
 {
     return GEOSPreparedIntersects_r( handle, pg1, g2 );
 }
 
+char
+GEOSPreparedOverlaps(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
+{
+    return GEOSPreparedOverlaps_r( handle, pg1, g2 );
+}
+
+char
+GEOSPreparedTouches(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
+{
+    return GEOSPreparedTouches_r( handle, pg1, g2 );
+}
+
+char
+GEOSPreparedWithin(const geos::geom::prep::PreparedGeometry *pg1, const Geometry *g2)
+{
+    return GEOSPreparedWithin_r( handle, pg1, g2 );
+}
+
 STRtree *
 GEOSSTRtree_create (size_t nodeCapacity)
 {
@@ -936,5 +1132,101 @@ GEOSInterpolateNormalized (const geos::geom::Geometry *g,
     return GEOSInterpolateNormalized_r(handle, g, d);
 }
 
+geos::geom::Geometry *
+GEOSGeom_extractUniquePoints (const geos::geom::Geometry *g)
+{
+    return GEOSGeom_extractUniquePoints_r(handle, g);
+}
+
+geos::geom::Geometry *
+GEOSGeom_createEmptyCollection(int type)
+{
+    return GEOSGeom_createEmptyCollection_r(handle, type);
+}
+
+geos::geom::Geometry *
+GEOSGeom_createEmptyPoint()
+{
+    return GEOSGeom_createEmptyPoint_r(handle);
+}
+
+geos::geom::Geometry *
+GEOSGeom_createEmptyLineString()
+{
+    return GEOSGeom_createEmptyLineString_r(handle);
+}
+
+geos::geom::Geometry *
+GEOSGeom_createEmptyPolygon()
+{
+    return GEOSGeom_createEmptyPolygon_r(handle);
+}
+
+int
+GEOSOrientationIndex(double Ax, double Ay, double Bx, double By,
+	double Px, double Py)
+{
+    return GEOSOrientationIndex_r(handle, Ax, Ay, Bx, By, Px, Py);
+}
+
+GEOSGeometry *
+GEOSSharedPaths(const GEOSGeometry* g1, const GEOSGeometry* g2)
+{
+    return GEOSSharedPaths_r(handle, g1, g2);
+}
+
+GEOSGeometry *
+GEOSSnap(const GEOSGeometry* g1, const GEOSGeometry* g2, double tolerance)
+{
+  return GEOSSnap_r(handle, g1, g2, tolerance);
+}
+
+GEOSBufferParams*
+GEOSBufferParams_create()
+{
+  return GEOSBufferParams_create_r(handle);
+}
+
+void
+GEOSBufferParams_destroy(GEOSBufferParams* p)
+{
+  return GEOSBufferParams_destroy_r(handle, p);
+}
+
+int
+GEOSBufferParams_setEndCapStyle(GEOSBufferParams* p, int style)
+{
+  return GEOSBufferParams_setEndCapStyle_r(handle, p, style);
+}
+
+int
+GEOSBufferParams_setJoinStyle(GEOSBufferParams* p, int joinStyle)
+{
+  return GEOSBufferParams_setJoinStyle_r(handle, p, joinStyle);
+}
+
+int
+GEOSBufferParams_setMitreLimit(GEOSBufferParams* p, double l)
+{
+  return GEOSBufferParams_setMitreLimit_r(handle, p, l);
+}
+
+int
+GEOSBufferParams_setQuadrantSegments(GEOSBufferParams* p, int joinStyle)
+{
+  return GEOSBufferParams_setQuadrantSegments_r(handle, p, joinStyle);
+}
+
+int
+GEOSBufferParams_setSingleSided(GEOSBufferParams* p, int singleSided)
+{
+  return GEOSBufferParams_setSingleSided_r(handle, p, singleSided);
+}
+
+Geometry*
+GEOSBufferWithParams(const Geometry* g, const GEOSBufferParams* p, double w)
+{
+  return GEOSBufferWithParams_r(handle, g, p, w);
+}
 
 } /* extern "C" */
