@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Geometry.h 3255 2011-03-01 17:56:10Z mloskot $
+ * $Id: Geometry.h 3538 2011-12-09 10:44:54Z strk $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -876,6 +876,14 @@ std::string geosversion();
  */
 std::string jtsport();
 
+// We use this instead of std::pair<auto_ptr<Geometry>> because C++11
+// forbids that construct:
+// http://lwg.github.com/issues/lwg-closed.html#2068
+struct GeomPtrPair {
+	typedef std::auto_ptr<Geometry> GeomPtr;
+	GeomPtr first;
+	GeomPtr second;
+};
 
 } // namespace geos::geom
 } // namespace geos
