@@ -1,17 +1,17 @@
-// $Id: isPointInRingTest.cpp 2184 2008-09-16 20:13:55Z mloskot $
+// $Id: isPointInRingTest.cpp 2344 2009-04-09 21:46:30Z mloskot $
 // 
 // Test Suite for CGAlgorithms::isPointInRing() function
 
-// GEOS
+// tut
+#include <tut.hpp>
+// geos
 #include <geos/algorithm/CGAlgorithms.h>
 #include <geos/geom/Polygon.h>
 #include <geos/geom/Geometry.h>
 #include <geos/geom/CoordinateSequence.h>
 #include <geos/geom/Coordinate.h>
 #include <geos/io/WKTReader.h>
-// TUT
-#include <tut.h>
-// STL
+// std
 #include <string>
 #include <cassert>
 
