@@ -1,8 +1,10 @@
-// $Id: ConvexHullTest.cpp 2167 2008-08-19 00:18:04Z mloskot $
+// $Id: ConvexHullTest.cpp 2344 2009-04-09 21:46:30Z mloskot $
 // 
 // Test Suite for geos::algorithm::ConvexHull
 // Ported from JTS junit/algorithm/ConvexHullTest.java
 
+#include <tut.hpp>
+#include <utility.h>
 // geos
 #include <geos/algorithm/ConvexHull.h>
 #include <geos/geom/LineString.h>
@@ -17,9 +19,6 @@
 #include <sstream>
 #include <memory>
 #include <cassert>
-// tut
-#include <tut.h>
-#include <utility.h>
 
 namespace geos {
 	namespace geom {
