@@ -1,4 +1,4 @@
-// $Id: GeometryFactoryTest.cpp 2761 2009-12-03 18:56:25Z mloskot $
+// $Id: GeometryFactoryTest.cpp 3255 2011-03-01 17:56:10Z mloskot $
 // 
 // Test Suite for geos::geom::GeometryFactory class.
 
@@ -760,7 +760,8 @@ namespace tut
 		GeometryPtr geo = reader_.read(("LINEARRING(7 7, 12 7, 12 12, 7 12, 7 7)"));
 		ensure( geo != 0 );
 
-		LinearRingPtr hole = static_cast<LinearRingPtr>(geo);
+		LinearRingPtr hole = dynamic_cast<LinearRingPtr>(geo);
+		ensure( hole != 0 );
 		ensure( hole->isRing() );
 		ensure_equals( hole->getNumPoints(), interiorSize );
 
@@ -1236,4 +1237,48 @@ namespace tut
 		//inform("Test not implemented!");
 	}
 
+	// Test of
+  // buildGeometry(from, to, takeOwnership) const
+	template<>
+	template<>
+	void object::test<36>()
+	{
+    typedef std::auto_ptr<geos::geom::Geometry> GeometryAutoPtr;
+		typedef std::vector<PointPtr> PointVect;
+
+		const std::size_t size = 3;
+		geos::geom::Coordinate coord(x_, y_, z_);
+
+		PointVect vec;
+
+		PointPtr geo = 0;
+		geo = factory_.createPoint(coord);
+		vec.push_back(geo);
+
+		coord.x *= 2;
+		coord.y *= 2;
+		coord.z *= 2;
+		geo = factory_.createPoint(coord);
+		vec.push_back(geo);
+
+		coord.x *= 3;
+		coord.y *= 3;
+		coord.z *= 3;
+		geo = factory_.createPoint(coord);
+		vec.push_back(geo);
+
+		// Factory creates copy of the vec collection
+		GeometryAutoPtr g = factory_.buildGeometry(vec.begin(), vec.end());
+		ensure( g.get() != 0 );
+		ensure_equals( g->getGeometryTypeId(), geos::geom::GEOS_MULTIPOINT );
+		ensure_equals( g->getNumGeometries(), size );
+
+		// FREE MEMORY
+		PointVect::const_iterator it;
+		for (it = vec.begin(); it != vec.end(); ++it)
+		{
+			delete (*it);
+		}
+	}
+
 } // namespace tut
