@@ -1,4 +1,4 @@
-// $Id: LinearRingTest.cpp 2761 2009-12-03 18:56:25Z mloskot $
+// $Id: LinearRingTest.cpp 3241 2011-02-23 15:45:40Z strk $
 // 
 // Test Suite for geos::geom::LinearRing class.
 
@@ -56,7 +56,7 @@ namespace tut
 			// Create non-empty LinearRing
 			GeometryPtr geo = 0;
 			geo = reader_.read("LINEARRING(0 10, 5 5, 10 5, 15 10, 10 15, 5 15, 0 10)");
-			ring_ = static_cast<LinearRingPtr>(geo);
+			ring_ = dynamic_cast<LinearRingPtr>(geo);
 		}
 
 		~test_linearring_data()
@@ -141,7 +141,7 @@ namespace tut
 	template<>
 	void object::test<4>()
 	{
-		ensure( ! empty_ring_.isClosed() );
+		ensure( empty_ring_.isClosed() );
 	}
 
 	// Test of isRing() for empty LinearRing
@@ -149,7 +149,7 @@ namespace tut
 	template<>
 	void object::test<5>()
 	{
-		ensure( ! empty_ring_.isRing() );
+		ensure( empty_ring_.isRing() );
 	}
 
 	// Test of isSimple() for empty LinearRing
@@ -411,7 +411,7 @@ namespace tut
 			GeometryPtr geo = reader_.read("LINEARRING(0 0, 5 5, 10 10, 15 5, 5 5, 0 10)");
 			ensure(geo != 0);
 
-			LinearRingPtr ring = static_cast<LinearRingPtr>(geo);
+			LinearRingPtr ring = dynamic_cast<LinearRingPtr>(geo);
 			ensure(ring != 0);
 
 			ensure( !ring->isValid() );
