@@ -1,10 +1,9 @@
-// $Id: MultiPolygonTest.cpp 1842 2006-09-07 15:28:03Z strk $
+// $Id: MultiPolygonTest.cpp 2344 2009-04-09 21:46:30Z mloskot $
 // 
 // Test Suite for geos::geom::MultiPolygon class.
 
-// TUT
-#include <tut.h>
-// GEOS
+#include <tut.hpp>
+// geos
 #include <geos/geom/MultiPolygon.h>
 
 namespace tut
